June 30, 2014 - Colorado Supreme Court Opinions

| CBA Home | CLE Home | Contact Us | Cart - empty
Log On My Cobar
| ## Search |
| CBA CLE About Us Membership For Lawyers STRATUM Colorado Mentoring Program COLTAF Representing the Moderate Income Client Casemaker The Colorado Lawyer Opinions/ Rules/ Statutes By Practice Area Practice Management Find A Lawyer Colorado Courts Website Continuing Legal Education Ethics Professionalism Resources Pro Bono Information - Make History Colorado Attorney Registration E-Filing Legislative Matters Employment Listserves Law Related Websites Litigators Handbook Volunteer Opportunities Join the CBA Confidential Assistance for Attorneys Help - FAQs Young Lawyers Division Inside the Bar News/Media Resources For the Public From the Courts Volunteer Opportunities Employment/Classified Ads
| Colorado Supreme Court Opinions June 30, 2014 2014 CO 54. No. 12SC610. Francen v. Department of Revenue, Division of Motor Vehicles. CRS § 42-2-126?Driver?s License Revocation?Probable Cause?Exclusionary Rule. The Department of Revenue, through the Division of Motor Vehicles, revoked a driver’s license, following a hearing officer’s determination that the driver had driven a motor vehicle with a blood alcohol content (BAC) in excess of the statutory maximum. The district court reversed, holding that the initial stop of the driver’s vehicle was not supported by reasonable suspicion. The court of appeals reversed the district court and held that the legality of the initial contact between the police and the driver was not relevant in the civil administrative proceeding to revoke the driver’s license. The court also held that the exclusionary rule did not apply to suppress evidence of the driver’s BAC. The Supreme Court held that, under CRS § 42-2-126, “probable cause” in the context of the driver’s license revocation statute, as it existed at the time of the hearing in this case, refers to the quantum and quality of evidence necessary for a law enforcement officer to issue a notice of driver’s license revocation, not whether the officer’s initial contact with the driver was lawful. The Supreme Court further held that the exclusionary rule did not apply to suppress evidence of the driver’s BAC in the driver’s license revocation proceeding. Accordingly, the Supreme Court affirmed the judgment of the court of appeals. 2014 CO 55. No. 12SC788. Hanson v. Department of Revenue, Division of Motor Vehicles. CRS § 42-2-126?Driver?s License Revocation?Probable Cause?Exclusionary Rule. The Division of Motor Vehicles revoked a driver’s license, following a hearing officer’s determination that the driver had improperly refused a blood alcohol test. The district court and the court of appeals both affirmed the revocation. The Supreme Court held that under CRS § 42-2-126, as it was in effect at the time of the hearing in this case, “probable cause” in the context of the driver’s license revocation statute refers to the quantum and quality of evidence necessary for a law enforcement officer to issue a notice of driver’s license revocation, not whether the officer’s initial contact with the driver was lawful. The Supreme Court further held that the exclusionary rule does not apply in driver’s license revocation proceedings. Accordingly, the Supreme Court affirmed the judgment of the court of appeals. 2014 CO 56. No. 11SC215. Sanchez v. People. Criminal Law?Miranda Warnings. Defendant petitioned for review of the court of appeals’ judgment in People v. Sanchez (Colo.App. No. 08CA630, Feb. 10, 2011) (not published pursuant to CAR 35(f)), which affirmed his conviction of first-degree murder. Among other things, defendant assigned error to the district court’s denial of his motion to suppress, as a violation of his Miranda rights, statements he made to the New Mexico police shortly after his arrest. In particular, he objected that he was not advised and did not understand that he would not ultimately be obligated to pay for an appointed attorney. The court of appeals rejected defendant’s assignment of error, concluding that the advisement he received concerning his right to appointed counsel was sufficient to convey to him that if he could not afford one, an attorney would be provided free of charge. The Supreme Court affirmed the judgment of the court of appeals. Miranda v. Arizona does not require that a suspect be advised of or understand that he or she will not ultimately bear any liability for the cost of an attorney appointed to assist him or her during custodial interrogation. Here, defendant was adequately advised and understood that if he requested the assistance of an attorney to consult with him and be present during custodial interrogation, but could not afford one, one would be appointed for that purpose. 2014 CO 57. No. 11SC935. Benefield v. Colorado Republican Party. CRS § 24-72-204(5)?Records?Costs and Fees. Benefield and other current or former members of the Colorado House of Representatives sought review of the court of appeals’ judgment in Colorado Republican Party v. Benefield (Colo.App. No. 10CA2327, Nov. 10, 2011), which reversed the district court’s order denying costs and attorney fees for the Colorado Republican Party. After assessing the extent to which the Party prevailed overall in its action for inspection of public records, the district court determined that it was not a “prevailing applicant” within the meaning of CRS § 24-72-204(5). The court of appeals reversed, reasoning that a prevailing applicant was “any party who brings a section 24-72-204(5) action against a public records custodian and obtains any improperly withheld public record as a result of such action.” The Supreme Court affirmed. CRS § 24-72-204(5), when properly construed, mandates an award of costs and reasonable attorney fees in favor of any person who applies for and receives an order from the district court requiring a custodian to permit inspection of a public record, as provided for by the statute. 2014 CO 58. Nos. 13SA91 & 13SA94. In Re People v. Owens. CAR 21 Original Proceeding?Death Penalty?CRS §§ 16-12-201 to -210?Discovery and Disclosure. Owens and Ray petitioned pursuant to CAR 21 for relief from a series of discovery rulings of the district court relative to post-conviction proceedings in their respective death penalty cases. Each had moved to discover the prosecution’s investigation of the claims raised by Owens’s motion for post-conviction review, on the grounds that such disclosure was required either by Crim.P. 16 or by the federal or state constitution. The district court ruled that Crim.P. 16 did not impose obligations on the prosecution with respect to its preparation to meet defendants’ post-conviction claims, but that the prosecution continued to have obligations to disclose information that was both exculpatory and constitutionally material, without regard for the time of or impetus for its discovery. The Supreme Court issued a rule to show cause why the district court’s ruling should not be disapproved for too narrowly limiting the prosecution’s discovery obligations during the unitary review proceedings prescribed by statute for all death sentences and convictions resulting in death sentences in this jurisdiction. The Court held that because Crim.P. 16 imposes disclosure obligations on the prosecution only with regard to materials and information acquired before or during trial, the district court did not err in finding it inapplicable to information acquired in response to defendants’ post-conviction claims. However, because the Court previously has held not only that a prosecutor’s constitutional obligation to disclose information favorable to an accused extends through the appeal of a death sentence, but also that district courts should order the disclosure of some possibly exculpatory material, despite being unable to find a reasonable probability that nondisclosure would change the result of the proceeding, the Court remanded the cases with directions for the district court to apply the due process standard and procedure announced in People v. Rodriguez, 786 P.2d 1079 (Colo. 1989). 2014 CO 59. No. 11SC759. Department of Revenue v. Public Service Co. Taxation?Sales Tax?Statutes?Construction. The Colorado Department of Revenue petitioned for certiorari review of the court of appeals’ decision affirming respondent’s entitlement to a sales and use tax refund. The Supreme Court granted certiorari and now reversed. Respondent Public Service Co. claimed that it is entitled to a sales and use tax refund for sales and use taxes paid on machinery purchased for the generation of electricity. CRS §§ 39-26-709 and 39-30-106 provide a sales and use tax exemption for machinery used for the production of tangible personal property. Public Service Co. argued that electricity constitutes tangible personal property and that it therefore is entitled to the sales and use tax exemption for its machinery used in the production of electricity. The Court held that electricity is treated as a service, not as tangible personal property, under the sales and use tax statutes. Therefore, Public Service Co. is not entitled to the machinery tax exemption. 2014 CO 60. No. 12SC235. People v. Carbajal. Colo. Const. art. II, § 13?Right to Bear Arms?Possession of a Weapon by a Previous Offender?Choice of Evils?Jury Instructions?Affirmative Defense. Reversing the court of appeals, the Supreme Court held that the trial court did not err in instructing the jury that, to raise an affirmative defense to possession of a weapon by a previous offender (POWPO), defendant must show that he possessed the weapon for the purpose of defending himself, his home, or his property from what he reasonably believed to be a threat of imminent harm. This instruction properly reflects the Court’s precedent in People v. Blue, 544 P.2d 385, 391 (1975), which upheld the POWPO statute against a claim that it unconstitutionally infringed on the right to bear arms under Colo. Const. art. II, § 13, based on the legislature’s provision of a choice of evils affirmative defense. Because the choice of evils defense includes both a reasonableness and imminence requirement, the trial court did not err in including these requirements in its instruction. 2014 CO 61. No. 14SA137. In the Matter of the Title, Ballot Title, and Submission Clause for 2013?2014 #103: Cordero v. Doe and Title Board. Initiative Procedure?CRS § 1-40-106(4)(d)? Absence of Designated Representatives From Title Board Meetings?Substitution of Designated Representatives. The Supreme Court held that CRS § 1-40-106(4)(d) does not allow designated representatives who are unable to attend a Title Board meeting to substitute alternates to serve in their place. Instead, the Title Board must delay its considerations until the next meeting, at which both designated representatives who were so designated at the initial stages of the initiative process are able to attend the Title Board meeting. 2014 CO 62. Nos. 14SA116, 14SA119, 14SA122. In the Matter of the Title, Ballot Title, and Submission Clause for 2013?2014 #85: Cordero v. Leahy and Title Board. Single Subject?Clear Title. The Supreme Court held that Initiatives #85, #86, and #87 each contains one subject—the creation of a statewide setback from occupied structures for new oil and gas wells. The Court also held that the titles set by the Title Board fairly reflect the purpose of the initiatives and are not misleading. The Court therefore affirmed the actions of the Title Board. 2014 CO 63. Nos. 14SA121 & 14SA124. In the Matter of the Title, Ballot Title and Submission Clause for 2013?2014 #90: Cordero v. Leahy and Title Board. Single Subject?Clear Title. The Supreme Court held that Initiatives #90 and #93 each contains one subject—the expansion of local governments’ authority to enact laws regulating oil and gas development that are more restrictive than state law. The Court also held that the titles set by the Title Board fairly reflect the purpose of the initiatives and are not misleading. The Court therefore affirmed the actions of the Title Board. 2014 CO 64. No. 13SC995. People in Interest of S.N. Dependency and Neglect Adjudication?Prospective Harm?Summary Judgment. The Supreme Court granted certiorari to consider whether summary judgment is ever appropriate in a dependency and neglect adjudication involving prospective harm. The Court held that courts must evaluate whether summary judgment is appropriate in such instances on a case-by-case basis. Accordingly, the Court reversed the judgment of the court of appeals and remanded the case to that court for proceedings consistent with this opinion. 2014 CO 65. No. 14SA74. People v. N.A.S. Juvenile Custody Under Miranda?Voluntariness and Coercion. In this interlocutory appeal, the People sought review of the trial court’s order suppressing statements of the juvenile defendant. The trial court found that defendant was in custody when he made the statements; that he did not waive his Miranda rights knowingly, voluntarily, or intelligently; and that the statements were involuntary. The Supreme Court held that, in light of the totality of the circumstances, defendant was not in custody when he made the statements, and he spoke voluntarily. Accordingly, the Court reversed the trial court’s suppression order and remanded for proceedings consistent with this opinion. 2014 CO 66. No. 14SA126. In the Matter of the Title, Ballot Title, and Submission Clause for 2013?2014 #89: Kemper v. Leahy and Title Board. Single Subject?Clear Title. In this case, the Supreme Court held that Initiative #89 contains a single subject and that the title clearly expresses the single subject. The Court thus affirmed the action of the Title Board. 2014 CO 67. No. 11SC792. Gibbons v. People. Modified Allen Jury Instruction. The Supreme Court overruled People v. Raglin, 21 P.3d 419 (Colo.App. 2000), in which a division of the court of appeals held that a modified Allen instruction [See Allen v. People, 660 P.2d 896, 898 (Colo. 1983).] “must inform the jurors that if it appears to the trial court that a unanimous decision cannot be reached, they will be excused and a mistrial declared.” The Court held that a trial court is not required to provide a mistrial advisement when giving a modified Allen instruction. The trial court has discretion to instruct a deadlocked jury about the possibility of a mistrial when, considering the content of the instruction and the context in which it is given, the instruction will not have a coercive effect on the jury. The court should consider exercising its discretion in rare circumstances—for example, when a jury has indicated a mistaken belief in indefinite deliberations. Applying this holding, the Court concluded that the trial court did not err by failing to instruct the jury about the possibility of a mistrial. The judgment was affirmed. 2014 CO 68. No. 11SC455. Martin v. People. Modified Allen Jury Instruction. The Supreme Court overruled People v. Raglin, 21 P.3d 419 (Colo.App. 2000), in which a division of the court of appeals held that a modified Allen instruction [See Allen v. People, 660 P.2d 896, 898 (Colo. 1983).] “must inform the jurors that if it appears to the trial court that a unanimous decision cannot be reached, they will be excused and a mistrial declared.” The Supreme Court held that a trial court is not required to provide a mistrial advisement when giving a modified Allen instruction. The trial court has discretion to instruct a deadlocked jury about the possibility of a mistrial when, considering the content of the instruction and the context in which it is given, the instruction will not have a coercive effect on the jury. The court should consider exercising its discretion in rare circumstances—for example, when a jury has indicated a mistaken belief in indefinite deliberations. Applying this holding, the Court concluded that the trial court did not err by failing to instruct the jury about the possibility of a mistrial. The judgment was affirmed. 2014 CO 69. No. 12SC46. Fain v. People. Modified Allen Jury Instruction. The Supreme Court overruled People v. Raglin, 21 P.3d 419 (Colo.App. 2000), in which a division of the court of appeals held that a modified Allen instruction [See Allen v. People, 660 P.2d 896, 898 (Colo. 1983).] “must inform the jurors that if it appears to the trial court that a unanimous decision cannot be reached, they will be excused and a mistrial declared.” The Supreme Court held that a trial court is not required to provide a mistrial advisement when giving a modified Allen instruction. The trial court has discretion to instruct a deadlocked jury about the possibility of a mistrial when, considering the content of the instruction and the context in which it is given, the instruction will not have a coercive effect on the jury. The court should consider exercising its discretion in rare circumstances—for example, when a jury has actually indicated a mistaken belief in indefinite deliberations. Applying this holding, the Court concluded that the trial court did not err by failing to instruct the jury about the possibility of a mistrial. The judgment was affirmed. Colorado Supreme Court Opinions Back |